@@ -6,7 +6,10 @@ object inherit from.  It provides shared methods for all container types.
 """
 
 from copy import deepcopy
+
+from neo.core import filters
 from neo.core.baseneo import BaseNeo, _reference_name, _container_name
+from neo.core.objectlist import ObjectList
 from neo.core.spiketrain import SpikeTrain
 from neo.core.spiketrainlist import SpikeTrainList
 
@@ -17,8 +20,7 @@ def unique_objs(objs):
     using the "is" test.
     """
     seen = set()
-    return [obj for obj in objs
-            if id(obj) not in seen and not seen.add(id(obj))]
+    return [obj for obj in objs if id(obj) not in seen and not seen.add(id(obj))]
 
 
 def filterdata(data, targdict=None, objects=None, **kwargs):
@@ -26,23 +28,25 @@ def filterdata(data, targdict=None, objects=None, **kwargs):
     Return a list of the objects in data matching *any* of the search terms
     in either their attributes or annotations.  Search terms can be
     provided as keyword arguments or a dictionary, either as a positional
-    argument after data or to the argument targdict.  targdict can also
+    argument after data or to the argument targdict.
+    A key of a provided dictionary is the name of the requested annotation
+    and the value is a FilterCondition object.
+    E.g.: Equal(x), LessThan(x), InRange(x, y).
+
+    targdict can also
     be a list of dictionaries, in which case the filters are applied
-    sequentially.  If targdict and kwargs are both supplied, the
+    sequentially.
+
+    A list of dictionaries is handled as follows: [ { or } and { or } ]
+    If targdict and kwargs are both supplied, the
     targdict filters are applied first, followed by the kwarg filters.
-    A targdict of None or {} and objects = None corresponds to no filters
-    applied, therefore returning all child objects.
-    Default targdict and objects is None.
-
-
-    objects (optional) should be the name of a Neo object type,
-    a neo object class, or a list of one or both of these.  If specified,
-    only these objects will be returned.
+    A targdict of None or {} corresponds to no filters applied, therefore
+    returning all child objects. Default targdict is None.
     """
 
     # if objects are specified, get the classes
     if objects:
-        if hasattr(objects, 'lower') or isinstance(objects, type):
+        if hasattr(objects, "lower") or isinstance(objects, type):
             objects = [objects]
     elif objects is not None:
         return []
@@ -52,7 +56,7 @@ def filterdata(data, targdict=None, objects=None, **kwargs):
         targdict = kwargs
     elif not kwargs:
         pass
-    elif hasattr(targdict, 'keys'):
+    elif hasattr(targdict, "keys"):
         targdict = [targdict, kwargs]
     else:
         targdict += [kwargs]
@@ -61,7 +65,7 @@ def filterdata(data, targdict=None, objects=None, **kwargs):
         results = data
 
     # if multiple dicts are provided, apply each filter sequentially
-    elif not hasattr(targdict, 'keys'):
+    elif not hasattr(targdict, "keys"):
         # for performance reasons, only do the object filtering on the first
         # iteration
         results = filterdata(data, targdict=targdict[0], objects=objects)
@@ -71,20 +75,25 @@ def filterdata(data, targdict=None, objects=None, **kwargs):
     else:
         # do the actual filtering
         results = []
-        for key, value in sorted(targdict.items()):
-            for obj in data:
-                if (hasattr(obj, key) and getattr(obj, key) == value and
-                        all([obj is not res for res in results])):
+        for obj in data:
+            for key, value in sorted(targdict.items()):
+                if hasattr(obj, key) and getattr(obj, key) == value:
                     results.append(obj)
-                elif (key in obj.annotations and obj.annotations[key] == value and
-                          all([obj is not res for res in results])):
+                    break
+                if isinstance(value, filters.FilterCondition) and key in obj.annotations:
+                    if value.evaluate(obj.annotations[key]):
+                        results.append(obj)
+                        break
+                if key in obj.annotations and obj.annotations[key] == value:
                     results.append(obj)
+                    break
+
+    # remove duplicates from results
+    results = list({id(res): res for res in results}.values())
 
     # keep only objects of the correct classes
     if objects:
-        results = [result for result in results if
-                   result.__class__ in objects or
-                   result.__class__.__name__ in objects]
+        results = [result for result in results if result.__class__ in objects or result.__class__.__name__ in objects]
 
     if results and all(isinstance(obj, SpikeTrain) for obj in results):
         return SpikeTrainList(results)
@@ -103,9 +112,7 @@ class Container(BaseNeo):
     Each class can define one or more of the following class attributes
     (in  addition to those of BaseNeo):
         :_container_child_objects: Neo container objects that can be children
-                                   of this object. This attribute is used in
-                                   cases where the child can only have one
-                                   parent of this type. An instance attribute
+                                   of this object. An instance attribute
                                    named class.__name__.lower()+'s' will be
                                    automatically defined to hold this child and
                                    will be initialized to an empty list.
@@ -114,45 +121,24 @@ class Container(BaseNeo):
                               class.__name__.lower()+'s' will be automatically
                               defined to hold this child and will be
                               initialized to an empty list.
-        :_multi_child_objects: Neo container objects that can be children
-                               of this object. This attribute is used in
-                               cases where the child can have multiple
-                               parents of this type. An instance attribute
-                               named class.__name__.lower()+'s' will be
-                               automatically defined to hold this child and
-                               will be initialized to an empty list.
-        :_child_properties: Properties that return sub-children of a particular
-                            type.  These properties must still be defined.
-                            This is mostly used for generate_diagram.
         :_repr_pretty_containers: The names of containers attributes printed
-                                  when pretty-printing using iPython.
+                                  when pretty-printing using IPython.
 
     The following helper properties are available
     (in  addition to those of BaseNeo):
-        :_single_child_objects: All neo container objects that can be children
-                                of this object and where the child can only
-                                have one parent of this type.
+        :_child_objects: All neo objects that can be children of this object.
                                 :_container_child_objects: +
                                 :_data_child_objects:
-        :_child_objects: All child objects.
-                         :_single_child_objects: + :_multi_child_objects:
         :_container_child_containers: The names of the container attributes
                                       used to store :_container_child_objects:
         :_data_child_containers: The names of the container attributes used
                                  to store :_data_child_objects:
         :_single_child_containers: The names of the container attributes used
                                    to store :_single_child_objects:
-        :_multi_child_containers: The names of the container attributes used
-                                  to store :_multi_child_objects:
-        :_child_containers: All child container attributes.
-                            :_single_child_containers: +
-                            :_multi_child_containers:
+        :_child_containers: All child container attributes. Same as :_single_child_containers:
         :_single_children: All objects that are children of the current object
                            where the child can only have one parent of
                            this type.
-        :_multi_children: All objects that are children of the current object
-                          where the child can have multiple parents of
-                          this type.
         :data_children: All data objects that are children of
                         the current object.
         :container_children: All container objects that are children of
@@ -181,20 +167,9 @@ class Container(BaseNeo):
                                          object recursively that are of a
                                          particular class.
 
-        :create_many_to_one_relationship(**args): For each child of the current
-                                                  object that can only have a
-                                                  single parent, set its parent
-                                                  to be the current object.
-
-        :create_many_to_many_relationship(**args): For children of the current
-                                                   object that can have more
-                                                   than one parent of this
-                                                   type, put the current
-                                                   object in the parent list.
-
-        :create_relationship(**args): Combines
-                                      :create_many_to_one_relationship: and
-                                      :create_many_to_many_relationship:
+        :create_relationship(**args): For each child of the current
+                                      object, set its parent
+                                      to be the current object.
 
         :merge(**args): Annotations are merged based on the rules of
                         :merge_annotations:.  Child objects with the same name
@@ -214,33 +189,49 @@ class Container(BaseNeo):
         2) process its non-universal recommended arguments (in its __new__ or
            __init__ method
     """
-    # Child objects that are a container and have a single parent
+
+    # Child objects that are a container
     _container_child_objects = ()
-    # Child objects that have data and have a single parent
+    # Child objects that have data
     _data_child_objects = ()
-    # Child objects that can have multiple parents
-    _multi_child_objects = ()
-    # Properties returning children of children [of children...]
-    _child_properties = ()
     # Containers that are listed when pretty-printing
     _repr_pretty_containers = ()
 
-    def __init__(self, name=None, description=None, file_origin=None,
-                 **annotations):
+    def __init__(self, name=None, description=None, file_origin=None, **annotations):
         """
         Initialize a new :class:`Container` instance.
         """
-        super().__init__(name=name, description=description,
-                         file_origin=file_origin, **annotations)
+        super().__init__(name=name, description=description, file_origin=file_origin, **annotations)
 
-        # initialize containers
-        for container in self._child_containers:
-            setattr(self, container, [])
+    def _get_object_list(self, name):
+        """
+        Return the container's ObjectList with the given (private) attribute name
+
+        Example:
+        >>> segment._get_object_list("_analogsignals")
+        """
+        return getattr(self, name)
+
+    def _set_object_list(self, name, value):
+        """
+        Set the contents of the container's ObjectList with the given (private) attribute name
+
+        Example:
+        >>> segment._set_object_list("_analogsignals", [sig1, sig2])
+        """
+        if isinstance(value, list):
+            object_list = getattr(self, name)
+            object_list.clear()
+            object_list.extend(value)
+        elif isinstance(value, ObjectList):  # from __iadd__
+            setattr(self, name, value)
+        else:
+            TypeError("value must be a list or an ObjectList")
 
     @property
-    def _single_child_objects(self):
+    def _child_objects(self):
         """
-        Child objects that have a single parent.
+        Return the names of the classes that can be children of this container.
         """
         return self._container_child_objects + self._data_child_objects
 
@@ -250,63 +241,31 @@ class Container(BaseNeo):
         Containers for child objects that are a container and
         have a single parent.
         """
-        return tuple([_container_name(child) for child in
-                      self._container_child_objects])
+        return tuple([_container_name(child) for child in self._container_child_objects])
 
     @property
     def _data_child_containers(self):
         """
         Containers for child objects that have data and have a single parent.
         """
-        return tuple([_container_name(child) for child in
-                      self._data_child_objects])
-
-    @property
-    def _single_child_containers(self):
-        """
-        Containers for child objects with a single parent.
-        """
-        return tuple([_container_name(child) for child in
-                      self._single_child_objects])
-
-    @property
-    def _multi_child_containers(self):
-        """
-        Containers for child objects that can have multiple parents.
-        """
-        return tuple([_container_name(child) for child in
-                      self._multi_child_objects])
-
-    @property
-    def _child_objects(self):
-        """
-        All types for child objects.
-        """
-        return self._single_child_objects + self._multi_child_objects
+        # the following construction removes the duplicate 'regionsofinterest'
+        # while preserving the child order (which `set()` would not do)
+        # I don't know if preserving the order is important, but I'm playing it safe
+        return tuple({_container_name(child): None for child in self._data_child_objects}.keys())
 
     @property
     def _child_containers(self):
         """
-        All containers for child objects.
+        Containers for child objects with a single parent.
         """
-        return self._single_child_containers + self._multi_child_containers
+        return tuple({_container_name(child): None for child in self._child_objects}.keys())
 
     @property
     def _single_children(self):
         """
         All child objects that can only have single parents.
         """
-        childs = [list(getattr(self, attr)) for attr in
-                  self._single_child_containers]
-        return tuple(sum(childs, []))
-
-    @property
-    def _multi_children(self):
-        """
-        All child objects that can have multiple parents.
-        """
-        childs = [list(getattr(self, attr)) for attr in
-                  self._multi_child_containers]
+        childs = [list(getattr(self, attr)) for attr in self._child_containers]
         return tuple(sum(childs, []))
 
     @property
@@ -315,8 +274,7 @@ class Container(BaseNeo):
         All data child objects stored in the current object.
         Not recursive.
         """
-        childs = [list(getattr(self, attr)) for attr in
-                  self._data_child_containers]
+        childs = [list(getattr(self, attr)) for attr in self._data_child_containers]
         return tuple(sum(childs, []))
 
     @property
@@ -325,9 +283,7 @@ class Container(BaseNeo):
         All container child objects stored in the current object.
         Not recursive.
         """
-        childs = [list(getattr(self, attr)) for attr in
-                  self._container_child_containers +
-                  self._multi_child_containers]
+        childs = [list(getattr(self, attr)) for attr in self._container_child_containers]
         return tuple(sum(childs, []))
 
     @property
@@ -344,8 +300,7 @@ class Container(BaseNeo):
         All data child objects stored in the current object,
         obtained recursively.
         """
-        childs = [list(child.data_children_recur) for child in
-                  self.container_children]
+        childs = [list(child.data_children_recur) for child in self.container_children]
         return self.data_children + tuple(sum(childs, []))
 
     @property
@@ -354,8 +309,7 @@ class Container(BaseNeo):
         All container child objects stored in the current object,
         obtained recursively.
         """
-        childs = [list(child.container_children_recur) for child in
-                  self.container_children]
+        childs = [list(child.container_children_recur) for child in self.container_children]
         return self.container_children + tuple(sum(childs, []))
 
     @property
@@ -372,18 +326,51 @@ class Container(BaseNeo):
         Get dictionary containing the names of child containers in the current
         object as keys and the number of children of that type as values.
         """
-        return {name: len(getattr(self, name))
-                    for name in self._child_containers}
+        return {name: len(getattr(self, name)) for name in self._child_containers}
 
-    def filter(self, targdict=None, data=True, container=False, recursive=True,
-               objects=None, **kwargs):
+    @property
+    def _container_lookup(self):
+        return {
+            cls_name: getattr(self, container_name)
+            for cls_name, container_name in zip(self._child_objects, self._child_containers)
+        }
+
+    def _get_container(self, cls):
+        if hasattr(cls, "proxy_for"):
+            cls = cls.proxy_for
+        return self._container_lookup[cls.__name__]
+
+    def add(self, *objects):
+        """Add a new Neo object to the Container"""
+        for obj in objects:
+            if obj.__class__.__name__ in self._child_objects or (
+                hasattr(obj, "proxy_for") and obj.proxy_for.__name__ in self._child_objects
+            ):
+                container = self._get_container(obj.__class__)
+                container.append(obj)
+            else:
+                raise TypeError(
+                    f"Cannot add object of type {obj.__class__.__name__} "
+                    f"to a {self.__class__.__name__}, can only add objects of the "
+                    f"following types: {self._child_objects}"
+                )
+
+    def filter(self, targdict=None, data=True, container=False, recursive=True, objects=None, **kwargs):
         """
         Return a list of child objects matching *any* of the search terms
         in either their attributes or annotations.  Search terms can be
         provided as keyword arguments or a dictionary, either as a positional
-        argument after data or to the argument targdict.  targdict can also
+        argument after data or to the argument targdict.
+        A key of a provided dictionary is the name of the requested annotation
+        and the value is a FilterCondition object.
+        E.g.: equal(x), less_than(x), InRange(x, y).
+
+        targdict can also
         be a list of dictionaries, in which case the filters are applied
-        sequentially.  If targdict and kwargs are both supplied, the
+        sequentially.
+
+        A list of dictionaries is handled as follows: [ { or } and { or } ]
+        If targdict and kwargs are both supplied, the
         targdict filters are applied first, followed by the kwarg filters.
         A targdict of None or {} corresponds to no filters applied, therefore
         returning all child objects. Default targdict is None.
@@ -406,22 +393,19 @@ class Container(BaseNeo):
             >>> obj.filter(name="Vm")
             >>> obj.filter(objects=neo.SpikeTrain)
             >>> obj.filter(targdict={'myannotation':3})
+            >>> obj.filter(name=neo.core.filters.Equal(5))
+            >>> obj.filter({'name': neo.core.filters.LessThan(5)})
         """
 
         if isinstance(targdict, str):
-            raise TypeError("filtering is based on key-value pairs."
-                            " Only a single string was provided.")
+            raise TypeError("filtering is based on key-value pairs." " Only a single string was provided.")
 
         # if objects are specified, get the classes
         if objects:
             data = True
             container = True
 
-        if objects == SpikeTrain:
-            children = SpikeTrainList()
-        else:
-            children = []
-
+        children = []
         # get the objects we want
         if data:
             if recursive:
@@ -434,8 +418,11 @@ class Container(BaseNeo):
             else:
                 children.extend(self.container_children)
 
-        return filterdata(children, objects=objects,
-                          targdict=targdict, **kwargs)
+        filtered = filterdata(children, objects=objects, targdict=targdict, **kwargs)
+        if objects == SpikeTrain:
+            return SpikeTrainList(items=filtered)
+        else:
+            return filtered
 
     def list_children_by_class(self, cls):
         """
@@ -444,7 +431,7 @@ class Container(BaseNeo):
         You can either provide a class object, a class name,
         or the name of the container storing the class.
         """
-        if not hasattr(cls, 'lower'):
+        if not hasattr(cls, "lower"):
             cls = cls.__name__
         container_name = _container_name(cls)
         objs = list(getattr(self, container_name, []))
@@ -452,18 +439,28 @@ class Container(BaseNeo):
             objs.extend(getattr(child, container_name, []))
         return objs
 
-    def create_many_to_one_relationship(self, force=False, recursive=True):
+    def check_relationships(self, recursive=True):
+        """
+        Check that the expected child-parent relationships exist.
+        """
+        parent_name = _reference_name(self.__class__.__name__)
+        for child in self._single_children:
+            if hasattr(child, "proxy_for"):
+                container = getattr(self, _container_name(child.proxy_for.__name__))
+            else:
+                container = getattr(self, _container_name(child.__class__.__name__))
+            if container.parent is not None:
+                if getattr(child, parent_name, None) is not self:
+                    raise AttributeError("Child should have its parent as an attribute")
+        if recursive:
+            for child in self.container_children:
+                child.check_relationships(recursive=True)
+
+    def create_relationship(self, force=False, recursive=True):
         """
         For each child of the current object that can only have a single
         parent, set its parent to be the current object.
-
-        Usage:
-        >>> a_block.create_many_to_one_relationship()
-        >>> a_block.create_many_to_one_relationship(force=True)
-
-        If the current object is a :class:`Block`, you want to run
-        populate_RecordingChannel first, because this will create new objects
-        that this method will link up.
+        For children of the current object, put the current object in the parent list.
 
         If force is True overwrite any existing relationships
         If recursive is True descend into child objects and create
@@ -471,61 +468,11 @@ class Container(BaseNeo):
         """
         parent_name = _reference_name(self.__class__.__name__)
         for child in self._single_children:
-            if (hasattr(child, parent_name) and
-                        getattr(child, parent_name) is None or force):
+            if hasattr(child, parent_name) and getattr(child, parent_name) is None or force:
                 setattr(child, parent_name, self)
         if recursive:
             for child in self.container_children:
-                child.create_many_to_one_relationship(force=force,
-                                                      recursive=True)
-
-    def create_many_to_many_relationship(self, append=True, recursive=True):
-        """
-        For children of the current object that can have more than one parent
-        of this type, put the current object in the parent list.
-
-        If append is True add it to the list, otherwise overwrite the list.
-        If recursive is True descend into child objects and create
-        relationships there
-        """
-        parent_name = _container_name(self.__class__.__name__)
-        for child in self._multi_children:
-            if not hasattr(child, parent_name):
-                continue
-            if append:
-                target = getattr(child, parent_name)
-                if self not in target:
-                    target.append(self)
-                continue
-            setattr(child, parent_name, [self])
-
-        if recursive:
-            for child in self.container_children:
-                child.create_many_to_many_relationship(append=append,
-                                                       recursive=True)
-
-    def create_relationship(self, force=False, append=True, recursive=True):
-        """
-        For each child of the current object that can only have a single
-        parent, set its parent to be the current object.
-        For children of the current object that can have more than one parent
-        of this type, put the current object in the parent list.
-
-        If the current object is a :class:`Block`, you want to run
-        populate_RecordingChannel first, because this will create new objects
-        that this method will link up.
-
-        If force is True overwrite any existing relationships
-        If append is True add it to the list, otherwise overwrite the list.
-        If recursive is True descend into child objects and create
-        relationships there
-        """
-        self.create_many_to_one_relationship(force=force, recursive=False)
-        self.create_many_to_many_relationship(append=append, recursive=False)
-        if recursive:
-            for child in self.container_children:
-                child.create_relationship(force=force, append=append,
-                                          recursive=True)
+                child.create_relationship(force=force, recursive=True)
 
     def __deepcopy__(self, memo):
         """
@@ -569,8 +516,7 @@ class Container(BaseNeo):
         after the merge operation and should not be used further.
         """
         # merge containers with the same name
-        for container in (self._container_child_containers +
-                              self._multi_child_containers):
+        for container in self._container_child_containers:
             lookup = {obj.name: obj for obj in getattr(self, container)}
             ids = [id(obj) for obj in getattr(self, container)]
             for obj in getattr(other, container):
@@ -591,7 +537,7 @@ class Container(BaseNeo):
             for obj in getattr(other, container):
                 if id(obj) in ids:
                     pass
-                elif hasattr(obj, 'merge') and obj.name is not None and obj.name in lookup:
+                elif hasattr(obj, "merge") and obj.name is not None and obj.name in lookup:
                     ind = lookup[obj.name]
                     try:
                         newobj = getattr(self, container)[ind].merge(obj)
@@ -619,8 +565,8 @@ class Container(BaseNeo):
         for container in self._child_containers:
             objs = getattr(self, container)
             if objs:
-                vals.append('{} {}'.format(len(objs), container))
-        pp.text(', '.join(vals))
+                vals.append(f"{objs} {container}")
+        pp.text(", ".join(vals))
 
         if self._has_repr_pretty_attrs_():
             pp.breakable()
@@ -629,9 +575,9 @@ class Container(BaseNeo):
         for container in self._repr_pretty_containers:
             pp.breakable()
             objs = getattr(self, container)
-            pp.text("# {} (N={})".format(container, len(objs)))
-            for (i, obj) in enumerate(objs):
+            pp.text(f"# {container} (N={objs})")
+            for i, obj in enumerate(objs):
                 pp.breakable()
-                pp.text("%s: " % i)
+                pp.text(f"{i}: ")
                 with pp.indent(3):
                     pp.pretty(obj)
