@@ -4,7 +4,7 @@ from neo.rawio.biocamrawio import BiocamRawIO
 
 class BiocamIO(BiocamRawIO, BaseFromRaw):
     __doc__ = BiocamRawIO.__doc__
-    mode = 'file'
+    mode = "file"
 
     def __init__(self, filename):
         BiocamRawIO.__init__(self, filename=filename)
