@@ -4,7 +4,7 @@ from neo.rawio.intanrawio import IntanRawIO
 
 class IntanIO(IntanRawIO, BaseFromRaw):
     __doc__ = IntanRawIO.__doc__
-    _prefered_signal_group_mode = 'group-by-same-units'
+    _prefered_signal_group_mode = "group-by-same-units"
 
     def __init__(self, filename):
         IntanRawIO.__init__(self, filename=filename)
