@@ -8,7 +8,8 @@ class NeuroScopeIO(NeuroScopeRawIO, BaseFromRaw):
 
     Ref: http://neuroscope.sourceforge.net/
     """
-    _prefered_signal_group_mode = 'group-by-same-units'
+
+    _prefered_signal_group_mode = "group-by-same-units"
 
     def __init__(self, filename):
         NeuroScopeRawIO.__init__(self, filename=filename)
