@@ -27,7 +27,6 @@ import itertools
 from uuid import uuid4
 import warnings
 from packaging.version import Version
-from itertools import chain
 
 import quantities as pq
 import numpy as np
@@ -789,7 +788,7 @@ class NixIO(BaseIO):
 
         # link signals and image sequences
         objnames = []
-        for obj in chain(
+        for obj in itertools.chain(
             neo_group.analogsignals,
             neo_group.irregularlysampledsignals,
             neo_group.imagesequences,
@@ -805,7 +804,7 @@ class NixIO(BaseIO):
 
         # link events, epochs and spiketrains
         objnames = []
-        for obj in chain(
+        for obj in itertools.chain(
             neo_group.events,
             neo_group.epochs,
             neo_group.spiketrains,
