@@ -3,13 +3,10 @@ from neo.rawio.phyrawio import PhyRawIO
 
 
 class PhyIO(PhyRawIO, BaseFromRaw):
-    name = 'Phy IO'
+    name = "Phy IO"
     description = "Phy IO"
-    mode = 'dir'
+    mode = "dir"
 
     def __init__(self, dirname, load_amplitudes=False, load_pcs=False):
-        PhyRawIO.__init__(self,
-                          dirname=dirname,
-                          load_amplitudes=load_amplitudes,
-                          load_pcs=load_pcs)
+        PhyRawIO.__init__(self, dirname=dirname, load_amplitudes=load_amplitudes, load_pcs=load_pcs)
         BaseFromRaw.__init__(self, dirname)
