@@ -14,13 +14,14 @@ import io
 import numpy as np
 
 from .baserawio import (
-    BaseRawIO,
+    BaseRawWithBufferApiIO,
     _signal_channel_dtype,
     _signal_stream_dtype,
     _signal_buffer_dtype,
     _spike_channel_dtype,
     _event_channel_dtype,
 )
+from .utils import get_memmap_shape
 
 from neo.core import NeoReadWriteError
 
@@ -32,7 +33,7 @@ class StructFile(io.BufferedReader):
         return struct.unpack(fmt, self.read(struct.calcsize(fmt)))
 
 
-class MicromedRawIO(BaseRawIO):
+class MicromedRawIO(BaseRawWithBufferApiIO):
     """
     Class for reading  data from micromed (.trc).
 
@@ -46,10 +47,11 @@ class MicromedRawIO(BaseRawIO):
     rawmode = "one-file"
 
     def __init__(self, filename=""):
-        BaseRawIO.__init__(self)
+        BaseRawWithBufferApiIO.__init__(self)
         self.filename = filename
 
     def _parse_header(self):
+
         with open(self.filename, "rb") as fid:
             f = StructFile(fid)
 
@@ -63,6 +65,7 @@ class MicromedRawIO(BaseRawIO):
             rec_datetime = datetime.datetime(year + 1900, month, day, hour, minute, sec)
 
             Data_Start_Offset, Num_Chan, Multiplexer, Rate_Min, Bytes = f.read_f("IHHHH", offset=138)
+            sig_dtype = "u" + str(Bytes)
 
             # header version
             (header_version,) = f.read_f("b", offset=175)
@@ -95,17 +98,36 @@ class MicromedRawIO(BaseRawIO):
                 if zname != zname2.decode("ascii").strip(" "):
                     raise NeoReadWriteError("expected the zone name to match")
 
-            # raw signals memmap
-            sig_dtype = "u" + str(Bytes)
-            self._raw_signals = np.memmap(self.filename, dtype=sig_dtype, mode="r", offset=Data_Start_Offset).reshape(
-                -1, Num_Chan
-            )
+            # "TRONCA" zone define segments
+            zname2, pos, length = zones["TRONCA"]
+            f.seek(pos)
+            # this number avoid a infinite loop in case of corrupted  TRONCA zone (seg_start!=0 and trace_offset!=0)
+            max_segments = 100
+            self.info_segments = []
+            for i in range(max_segments):
+                # 4 bytes u4 each
+                seg_start = int(np.frombuffer(f.read(4), dtype="u4")[0])
+                trace_offset = int(np.frombuffer(f.read(4), dtype="u4")[0])
+                if seg_start == 0 and trace_offset == 0:
+                    break
+                else:
+                    self.info_segments.append((seg_start, trace_offset))
+
+            if len(self.info_segments) == 0:
+                # one unique segment = general case
+                self.info_segments.append((0, 0))
+
+            nb_segment = len(self.info_segments)
 
             # Reading Code Info
             zname2, pos, length = zones["ORDER"]
             f.seek(pos)
             code = np.frombuffer(f.read(Num_Chan * 2), dtype="u2")
 
+            # unique stream and buffer
+            buffer_id = "0"
+            stream_id = "0"
+
             units_code = {-1: "nV", 0: "uV", 1: "mV", 2: 1, 100: "percent", 101: "dimensionless", 102: "dimensionless"}
             signal_channels = []
             sig_grounds = []
@@ -128,21 +150,46 @@ class MicromedRawIO(BaseRawIO):
                 (sampling_rate,) = f.read_f("H")
                 sampling_rate *= Rate_Min
                 chan_id = str(c)
-                stream_id = "0"
-                buffer_id = "0"
                 signal_channels.append(
                     (chan_name, chan_id, sampling_rate, sig_dtype, units, gain, offset, stream_id, buffer_id)
                 )
 
             signal_channels = np.array(signal_channels, dtype=_signal_channel_dtype)
 
-            signal_buffers = np.array([("Signals", "0")], dtype=_signal_buffer_dtype)
-            signal_streams = np.array([("Signals", "0", "0")], dtype=_signal_stream_dtype)
+            self._stream_buffer_slice = {"0": slice(None)}
+            signal_buffers = np.array([("Signals", buffer_id)], dtype=_signal_buffer_dtype)
+            signal_streams = np.array([("Signals", stream_id, buffer_id)], dtype=_signal_stream_dtype)
 
             if np.unique(signal_channels["sampling_rate"]).size != 1:
                 raise NeoReadWriteError("The sampling rates must be the same across signal channels")
             self._sampling_rate = float(np.unique(signal_channels["sampling_rate"])[0])
 
+            # memmap traces buffer
+            full_signal_shape = get_memmap_shape(
+                self.filename, sig_dtype, num_channels=Num_Chan, offset=Data_Start_Offset
+            )
+            seg_limits = [trace_offset for seg_start, trace_offset in self.info_segments] + [full_signal_shape[0]]
+            self._t_starts = []
+            self._buffer_descriptions = {0: {}}
+            for seg_index in range(nb_segment):
+                seg_start, trace_offset = self.info_segments[seg_index]
+                self._t_starts.append(seg_start / self._sampling_rate)
+
+                start = seg_limits[seg_index]
+                stop = seg_limits[seg_index + 1]
+
+                shape = (stop - start, Num_Chan)
+                file_offset = Data_Start_Offset + (start * np.dtype(sig_dtype).itemsize * Num_Chan)
+                self._buffer_descriptions[0][seg_index] = {}
+                self._buffer_descriptions[0][seg_index][buffer_id] = {
+                    "type": "raw",
+                    "file_path": str(self.filename),
+                    "dtype": sig_dtype,
+                    "order": "C",
+                    "file_offset": file_offset,
+                    "shape": shape,
+                }
+
             # Event channels
             event_channels = []
             event_channels.append(("Trigger", "", "event"))
@@ -164,13 +211,13 @@ class MicromedRawIO(BaseRawIO):
                 dtype = np.dtype(ev_dtype)
                 rawevent = np.memmap(self.filename, dtype=dtype, mode="r", offset=pos, shape=length // dtype.itemsize)
 
-                keep = (
-                    (rawevent["start"] >= rawevent["start"][0])
-                    & (rawevent["start"] < self._raw_signals.shape[0])
-                    & (rawevent["start"] != 0)
-                )
-                rawevent = rawevent[keep]
-                self._raw_events.append(rawevent)
+                # important : all events timing are related to the first segment t_start
+                self._raw_events.append([])
+                for seg_index in range(nb_segment):
+                    left_lim = seg_limits[seg_index]
+                    right_lim = seg_limits[seg_index + 1]
+                    keep = (rawevent["start"] >= left_lim) & (rawevent["start"] < right_lim) & (rawevent["start"] != 0)
+                    self._raw_events[-1].append(rawevent[keep])
 
             # No spikes
             spike_channels = []
@@ -179,7 +226,7 @@ class MicromedRawIO(BaseRawIO):
             # fille into header dict
             self.header = {}
             self.header["nb_block"] = 1
-            self.header["nb_segment"] = [1]
+            self.header["nb_segment"] = [nb_segment]
             self.header["signal_buffers"] = signal_buffers
             self.header["signal_streams"] = signal_streams
             self.header["signal_channels"] = signal_channels
@@ -204,48 +251,40 @@ class MicromedRawIO(BaseRawIO):
         return self.filename
 
     def _segment_t_start(self, block_index, seg_index):
-        return 0.0
+        return self._t_starts[seg_index]
 
     def _segment_t_stop(self, block_index, seg_index):
-        t_stop = self._raw_signals.shape[0] / self._sampling_rate
-        return t_stop
-
-    def _get_signal_size(self, block_index, seg_index, stream_index):
-        if stream_index != 0:
-            raise ValueError("`stream_index` must be 0")
-        return self._raw_signals.shape[0]
+        duration = self.get_signal_size(block_index, seg_index, stream_index=0) / self._sampling_rate
+        return duration + self.segment_t_start(block_index, seg_index)
 
     def _get_signal_t_start(self, block_index, seg_index, stream_index):
-        if stream_index != 0:
-            raise ValueError("`stream_index` must be 0")
-        return 0.0
-
-    def _get_analogsignal_chunk(self, block_index, seg_index, i_start, i_stop, stream_index, channel_indexes):
-        if channel_indexes is None:
-            channel_indexes = slice(channel_indexes)
-        raw_signals = self._raw_signals[slice(i_start, i_stop), channel_indexes]
-        return raw_signals
+        assert stream_index == 0
+        return self._t_starts[seg_index]
 
     def _spike_count(self, block_index, seg_index, unit_index):
         return 0
 
     def _event_count(self, block_index, seg_index, event_channel_index):
-        n = self._raw_events[event_channel_index].size
+        n = self._raw_events[event_channel_index][seg_index].size
         return n
 
     def _get_event_timestamps(self, block_index, seg_index, event_channel_index, t_start, t_stop):
 
-        raw_event = self._raw_events[event_channel_index]
+        raw_event = self._raw_events[event_channel_index][seg_index]
+
+        # important : all events timing are related to the first segment t_start
+        seg_start0, _ = self.info_segments[0]
 
         if t_start is not None:
-            keep = raw_event["start"] >= int(t_start * self._sampling_rate)
+            keep = raw_event["start"] + seg_start0 >= int(t_start * self._sampling_rate)
             raw_event = raw_event[keep]
 
         if t_stop is not None:
-            keep = raw_event["start"] <= int(t_stop * self._sampling_rate)
+            keep = raw_event["start"] + seg_start0 <= int(t_stop * self._sampling_rate)
             raw_event = raw_event[keep]
 
-        timestamp = raw_event["start"]
+        timestamp = raw_event["start"] + seg_start0
+
         if event_channel_index < 2:
             durations = None
         else:
@@ -266,3 +305,6 @@ class MicromedRawIO(BaseRawIO):
     def _rescale_epoch_duration(self, raw_duration, dtype, event_channel_index):
         durations = raw_duration.astype(dtype) / self._sampling_rate
         return durations
+
+    def _get_analogsignal_buffer_description(self, block_index, seg_index, buffer_id):
+        return self._buffer_descriptions[block_index][seg_index][buffer_id]
