@@ -25,7 +25,10 @@ else:
 
     from zugbruecke import CtypesSession
 
-    ctypes = CtypesSession(log_level=100)
+    if platform.system() == "Darwin":
+        ctypes = CtypesSession(log_level=100, arch="win64")
+    else:
+        ctypes = CtypesSession(log_level=100)
 
 
 class tm(ctypes.Structure):
@@ -610,7 +613,7 @@ class PyPL2FileReader:
 
         self.pl2_dll.PL2_GetSpikeChannelInfoByName.argtypes = (
             ctypes.c_int,
-            ctypes.c_char * len(channel_name),
+            ctypes.POINTER(ctypes.c_char),
             ctypes.POINTER(PL2SpikeChannelInfo),
         )
 
@@ -629,11 +632,9 @@ class PyPL2FileReader:
         result = self.pl2_dll.PL2_GetSpikeChannelInfoByName(
             self._file_handle, channel_name, ctypes.byref(pl2_spike_channel_info)
         )
-
         if not result:
             self._print_error()
             return None
-
         return pl2_spike_channel_info
 
     def pl2_get_spike_channel_info_by_source(self, source_id, one_based_channel_index_in_source):
@@ -744,7 +745,7 @@ class PyPL2FileReader:
 
         self.pl2_dll.PL2_GetSpikeChannelDataByName.argtypes = (
             ctypes.c_int,
-            ctypes.c_char,
+            ctypes.POINTER(ctypes.c_char),
             ctypes.POINTER(ctypes.c_ulonglong),
             ctypes.POINTER(ctypes.c_ulonglong),
             ctypes.POINTER(ctypes.c_ushort),
