@@ -19,16 +19,13 @@ else:
     HAVE_IPYTHON = True
 
 from neo.core.segment import Segment
-from neo.core import (AnalogSignal, Block, Event, IrregularlySampledSignal,
-                      Epoch, SpikeTrain)
+from neo.core import AnalogSignal, Block, Event, IrregularlySampledSignal, Epoch, SpikeTrain
 from neo.core.spiketrainlist import SpikeTrainList
 from neo.core.container import filterdata
-from neo.test.tools import (assert_neo_object_is_compliant,
-                            assert_same_sub_schema, assert_same_attributes)
+from neo.test.tools import assert_neo_object_is_compliant, assert_same_sub_schema, assert_same_attributes
 from neo.test.generate_datasets import random_segment, simple_block
 from neo.rawio.examplerawio import ExampleRawIO
-from neo.io.proxyobjects import (AnalogSignalProxy, SpikeTrainProxy,
-                                 EventProxy, EpochProxy)
+from neo.io.proxyobjects import AnalogSignalProxy, SpikeTrainProxy, EventProxy, EpochProxy
 
 
 N_EXAMPLES = 5
@@ -40,9 +37,9 @@ class TestSegment(unittest.TestCase):
         self.segments = [random_segment() for i in range(N_EXAMPLES)]
 
     def test_init(self):
-        seg = Segment(name='a segment', index=3)
+        seg = Segment(name="a segment", index=3)
         assert_neo_object_is_compliant(seg)
-        self.assertEqual(seg.name, 'a segment')
+        self.assertEqual(seg.name, "a segment")
         self.assertEqual(seg.file_origin, None)
         self.assertEqual(seg.index, 3)
 
@@ -50,20 +47,16 @@ class TestSegment(unittest.TestCase):
         for seg in self.segments:
             # calculate target values for t_start and t_stop
             t_starts, t_stops = [], []
-            for children in [seg.analogsignals,
-                             seg.epochs,
-                             seg.events,
-                             seg.irregularlysampledsignals,
-                             seg.spiketrains]:
+            for children in [seg.analogsignals, seg.epochs, seg.events, seg.irregularlysampledsignals, seg.spiketrains]:
                 for child in children:
-                    if hasattr(child, 't_start'):
+                    if hasattr(child, "t_start"):
                         t_starts.append(child.t_start)
-                    if hasattr(child, 't_stop'):
+                    if hasattr(child, "t_stop"):
                         t_stops.append(child.t_stop)
-                    if hasattr(child, 'time'):
+                    if hasattr(child, "time"):
                         t_starts.append(child.time)
                         t_stops.append(child.time)
-                    if hasattr(child, 'times'):
+                    if hasattr(child, "times"):
                         t_starts.append(child.times[0])
                         t_stops.append(child.times[-1])
             targ_t_start = min(t_starts)
@@ -74,12 +67,12 @@ class TestSegment(unittest.TestCase):
 
         # Testing times with ProxyObjects
         seg = Segment()
-        reader = ExampleRawIO(filename='my_filename.fake')
+        reader = ExampleRawIO(filename="my_filename.fake")
         reader.parse_header()
 
-        proxy_anasig = AnalogSignalProxy(rawio=reader,
-                        stream_index=0, inner_stream_channels=None,
-                        block_index=0, seg_index=0)
+        proxy_anasig = AnalogSignalProxy(
+            rawio=reader, stream_index=0, inner_stream_channels=None, block_index=0, seg_index=0
+        )
         seg.analogsignals.append(proxy_anasig)
 
         proxy_st = SpikeTrainProxy(rawio=reader, spike_channel_index=0, block_index=0, seg_index=0)
@@ -92,20 +85,16 @@ class TestSegment(unittest.TestCase):
         seg.epochs.append(proxy_epoch)
 
         t_starts, t_stops = [], []
-        for children in [seg.analogsignals,
-                         seg.epochs,
-                         seg.events,
-                         seg.irregularlysampledsignals,
-                         seg.spiketrains]:
+        for children in [seg.analogsignals, seg.epochs, seg.events, seg.irregularlysampledsignals, seg.spiketrains]:
             for child in children:
-                if hasattr(child, 't_start'):
+                if hasattr(child, "t_start"):
                     t_starts.append(child.t_start)
-                if hasattr(child, 't_stop'):
+                if hasattr(child, "t_stop"):
                     t_stops.append(child.t_stop)
-                if hasattr(child, 'time'):
+                if hasattr(child, "time"):
                     t_starts.append(child.time)
                     t_stops.append(child.time)
-                if hasattr(child, 'times'):
+                if hasattr(child, "times"):
                     t_starts.append(child.times[0])
                     t_stops.append(child.times[-1])
         targ_t_start = min(t_starts)
@@ -120,11 +109,10 @@ class TestSegment(unittest.TestCase):
         orig_seg1 = deepcopy(seg1)
         seg1.merge(seg2)
 
-        assert_same_sub_schema(orig_seg1.analogsignals + seg2.analogsignals,
-                               seg1.analogsignals)
+        assert_same_sub_schema(orig_seg1.analogsignals + seg2.analogsignals, seg1.analogsignals)
         assert_same_sub_schema(
-            orig_seg1.irregularlysampledsignals + seg2.irregularlysampledsignals,
-            seg1.irregularlysampledsignals)
+            orig_seg1.irregularlysampledsignals + seg2.irregularlysampledsignals, seg1.irregularlysampledsignals
+        )
         assert_same_sub_schema(orig_seg1.epochs + seg2.epochs, seg1.epochs)
         assert_same_sub_schema(orig_seg1.events + seg2.events, seg1.events)
         assert_same_sub_schema(orig_seg1.spiketrains + seg2.spiketrains, seg1.spiketrains)
@@ -137,7 +125,7 @@ class TestSegment(unittest.TestCase):
                 "irregularlysampledsignals": len(segment.irregularlysampledsignals),
                 "spiketrains": len(segment.spiketrains),
                 "analogsignals": len(segment.analogsignals),
-                "imagesequences": len(segment.imagesequences)
+                "imagesequences": len(segment.imagesequences),
             }
             self.assertEqual(segment.size, targ1)
 
@@ -156,7 +144,7 @@ class TestSegment(unittest.TestCase):
             # and then we have to convert to a SpikeTrainList
             # to match the output of segment.filter
             if all(isinstance(obj, SpikeTrain) for obj in targ):
-                targ = SpikeTrainList(items=targ, segment=segment)
+                targ = SpikeTrainList(items=targ, parent=segment)
 
             res0 = segment.filter()
             res1 = segment.filter({})
@@ -185,10 +173,10 @@ class TestSegment(unittest.TestCase):
         targ = [segment.analogsignals[0], segment.spiketrains[1]]
 
         res0 = segment.filter(thing="wotsit")
-        res1 = segment.filter({'thing': "wotsit"})
-        res2 = segment.filter(targdict={'thing': "wotsit"})
-        res3 = segment.filter([{'thing': "wotsit"}])
-        res4 = segment.filter(targdict=[{'thing': "wotsit"}])
+        res1 = segment.filter({"thing": "wotsit"})
+        res2 = segment.filter(targdict={"thing": "wotsit"})
+        res3 = segment.filter([{"thing": "wotsit"}])
+        res4 = segment.filter(targdict=[{"thing": "wotsit"}])
 
         assert_same_sub_schema(res0, targ)
         assert_same_sub_schema(res1, targ)
@@ -201,10 +189,10 @@ class TestSegment(unittest.TestCase):
         targ = []
 
         res0 = segment.filter(j=5)
-        res1 = segment.filter({'j': 5})
-        res2 = segment.filter(targdict={'j': 5})
-        res3 = segment.filter([{'j': 5}])
-        res4 = segment.filter(targdict=[{'j': 5}])
+        res1 = segment.filter({"j": 5})
+        res2 = segment.filter(targdict={"j": 5})
+        res3 = segment.filter([{"j": 5}])
+        res4 = segment.filter(targdict=[{"j": 5}])
 
         assert_same_sub_schema(res0, targ)
         assert_same_sub_schema(res1, targ)
@@ -219,8 +207,8 @@ class TestSegment(unittest.TestCase):
 
         name = targ[0].name
         res0 = segment.filter(name=name)
-        res1 = segment.filter({'name': name})
-        res2 = segment.filter(targdict={'name': name})
+        res1 = segment.filter({"name": name})
+        res2 = segment.filter(targdict={"name": name})
 
         assert_same_sub_schema(res0, targ)
         assert_same_sub_schema(res1, targ)
@@ -231,8 +219,8 @@ class TestSegment(unittest.TestCase):
 
         name = "potato"
         res0 = segment.filter(name=name)
-        res1 = segment.filter({'name': name})
-        res2 = segment.filter(targdict={'name': name})
+        res1 = segment.filter({"name": name})
+        res2 = segment.filter(targdict={"name": name})
 
         self.assertEqual(len(res0), 0)
         self.assertEqual(len(res1), 0)
@@ -243,10 +231,7 @@ class TestSegment(unittest.TestCase):
         segment = simple_block().segments[1]
         targ = [segment.analogsignals[0], segment.irregularlysampledsignals[0]]
 
-        filter = {
-            "name": targ[0].name,
-            "thing": targ[0].annotations["thing"]
-        }
+        filter = {"name": targ[0].name, "thing": targ[0].annotations["thing"]}
 
         res0 = segment.filter(**filter)
         res1 = segment.filter(filter)
@@ -260,10 +245,7 @@ class TestSegment(unittest.TestCase):
         segment = simple_block().segments[0]
         targ = []
 
-        filter = {
-            "name": "carrot",
-            "thing": "another thing"
-        }
+        filter = {"name": "carrot", "thing": "another thing"}
 
         res0 = segment.filter(**filter)
         res1 = segment.filter(filter)
@@ -277,10 +259,7 @@ class TestSegment(unittest.TestCase):
         segment = simple_block().segments[1]
         targ = [segment.analogsignals[0], segment.irregularlysampledsignals[0]]
 
-        filter = {
-            "name": targ[0].name,
-            "thing": "another thing"
-        }
+        filter = {"name": targ[0].name, "thing": "another thing"}
 
         res0 = segment.filter(**filter)
         res1 = segment.filter(filter)
@@ -313,9 +292,9 @@ class TestSegment(unittest.TestCase):
         segment = simple_block().segments[0]
         targ = [segment.analogsignals[1]]
 
-        res0 = segment.filter(thing="frooble", objects='AnalogSignal')
+        res0 = segment.filter(thing="frooble", objects="AnalogSignal")
         res1 = segment.filter(thing="frooble", objects=AnalogSignal)
-        res2 = segment.filter(thing="frooble", objects=['AnalogSignal'])
+        res2 = segment.filter(thing="frooble", objects=["AnalogSignal"])
         res3 = segment.filter(thing="frooble", objects=[AnalogSignal])
 
         assert_same_sub_schema(res0, targ)
@@ -327,8 +306,7 @@ class TestSegment(unittest.TestCase):
         segment = simple_block().segments[0]
         targ = [segment.analogsignals[0], segment.spiketrains[1]]
 
-        res0 = segment.filter(thing="wotsit",
-                              objects=["Event", SpikeTrain, "AnalogSignal"])
+        res0 = segment.filter(thing="wotsit", objects=["Event", SpikeTrain, "AnalogSignal"])
 
         assert_same_sub_schema(res0, targ)
 
@@ -337,7 +315,7 @@ class TestSegment(unittest.TestCase):
         targ = []
 
         res0 = segment.filter(j=1, objects=Epoch)
-        res1 = segment.filter(j=1, objects='Epoch')
+        res1 = segment.filter(j=1, objects="Epoch")
         res2 = segment.filter(j=1, objects=[])
 
         assert_same_sub_schema(res0, targ)
@@ -429,28 +407,37 @@ class TestSegment(unittest.TestCase):
     #     self.assertEqual(res, targ)
 
     def test__time_slice(self):
-        time_slice = [.5, 5.6] * pq.s
+        time_slice = [0.5, 5.6] * pq.s
 
-        epoch2 = Epoch([0.6, 9.5, 16.8, 34.1] * pq.s, durations=[4.5, 4.8, 5.0, 5.0] * pq.s,
-                       t_start=.1 * pq.s)
-        epoch2.annotate(epoch_type='b')
+        epoch2 = Epoch([0.6, 9.5, 16.8, 34.1] * pq.s, durations=[4.5, 4.8, 5.0, 5.0] * pq.s, t_start=0.1 * pq.s)
+        epoch2.annotate(epoch_type="b")
         epoch2.array_annotate(trial_id=[1, 2, 3, 4])
 
-        event = Event(times=[0.5, 10.0, 25.2] * pq.s, t_start=.1 * pq.s)
-        event.annotate(event_type='trial start')
+        event = Event(times=[0.5, 10.0, 25.2] * pq.s, t_start=0.1 * pq.s)
+        event.annotate(event_type="trial start")
         event.array_annotate(trial_id=[1, 2, 3])
 
-        anasig = AnalogSignal(np.arange(50.0) * pq.mV, t_start=.1 * pq.s,
-                              sampling_rate=1.0 * pq.Hz)
-        irrsig = IrregularlySampledSignal(signal=np.arange(50.0) * pq.mV,
-                                          times=anasig.times, t_start=.1 * pq.s)
-        st = SpikeTrain(np.arange(0.5, 50, 7) * pq.s, t_start=.1 * pq.s, t_stop=50.0 * pq.s,
-                        waveforms=np.array([[[0., 1.], [0.1, 1.1]], [[2., 3.], [2.1, 3.1]],
-                                            [[4., 5.], [4.1, 5.1]], [[6., 7.], [6.1, 7.1]],
-                                            [[8., 9.], [8.1, 9.1]], [[12., 13.], [12.1, 13.1]],
-                                            [[14., 15.], [14.1, 15.1]],
-                                            [[16., 17.], [16.1, 17.1]]]) * pq.mV,
-                        array_annotations={'spikenum': np.arange(1, 9)})
+        anasig = AnalogSignal(np.arange(50.0) * pq.mV, t_start=0.1 * pq.s, sampling_rate=1.0 * pq.Hz)
+        irrsig = IrregularlySampledSignal(signal=np.arange(50.0) * pq.mV, times=anasig.times, t_start=0.1 * pq.s)
+        st = SpikeTrain(
+            np.arange(0.5, 50, 7) * pq.s,
+            t_start=0.1 * pq.s,
+            t_stop=50.0 * pq.s,
+            waveforms=np.array(
+                [
+                    [[0.0, 1.0], [0.1, 1.1]],
+                    [[2.0, 3.0], [2.1, 3.1]],
+                    [[4.0, 5.0], [4.1, 5.1]],
+                    [[6.0, 7.0], [6.1, 7.1]],
+                    [[8.0, 9.0], [8.1, 9.1]],
+                    [[12.0, 13.0], [12.1, 13.1]],
+                    [[14.0, 15.0], [14.1, 15.1]],
+                    [[16.0, 17.0], [16.1, 17.1]],
+                ]
+            )
+            * pq.mV,
+            array_annotations={"spikenum": np.arange(1, 9)},
+        )
 
         seg = Segment()
         seg.epochs = [epoch2]
@@ -461,7 +448,7 @@ class TestSegment(unittest.TestCase):
 
         block = Block()
         block.segments = [seg]
-        block.create_many_to_one_relationship()
+        block.check_relationships()
 
         # test without resetting the time
         sliced = seg.time_slice(time_slice[0], time_slice[1])
@@ -474,21 +461,13 @@ class TestSegment(unittest.TestCase):
         self.assertEqual(len(sliced.irregularlysampledsignals), 1)
         self.assertEqual(len(sliced.epochs), 1)
 
-        assert_same_attributes(sliced.spiketrains[0],
-                               st.time_slice(t_start=time_slice[0],
-                                             t_stop=time_slice[1]))
-        assert_same_attributes(sliced.analogsignals[0],
-                               anasig.time_slice(t_start=time_slice[0],
-                                                 t_stop=time_slice[1]))
-        assert_same_attributes(sliced.irregularlysampledsignals[0],
-                               irrsig.time_slice(t_start=time_slice[0],
-                                                 t_stop=time_slice[1]))
-        assert_same_attributes(sliced.events[0],
-                               event.time_slice(t_start=time_slice[0],
-                                                t_stop=time_slice[1]))
-        assert_same_attributes(sliced.epochs[0],
-                               epoch2.time_slice(t_start=time_slice[0],
-                                                 t_stop=time_slice[1]))
+        assert_same_attributes(sliced.spiketrains[0], st.time_slice(t_start=time_slice[0], t_stop=time_slice[1]))
+        assert_same_attributes(sliced.analogsignals[0], anasig.time_slice(t_start=time_slice[0], t_stop=time_slice[1]))
+        assert_same_attributes(
+            sliced.irregularlysampledsignals[0], irrsig.time_slice(t_start=time_slice[0], t_stop=time_slice[1])
+        )
+        assert_same_attributes(sliced.events[0], event.time_slice(t_start=time_slice[0], t_stop=time_slice[1]))
+        assert_same_attributes(sliced.epochs[0], epoch2.time_slice(t_start=time_slice[0], t_stop=time_slice[1]))
 
         seg = Segment()
         seg.epochs = [epoch2]
@@ -499,7 +478,7 @@ class TestSegment(unittest.TestCase):
 
         block = Block()
         block.segments = [seg]
-        block.create_many_to_one_relationship()
+        block.check_relationships()
 
         # test with resetting the time
         sliced = seg.time_slice(time_slice[0], time_slice[1], reset_time=True)
@@ -512,46 +491,48 @@ class TestSegment(unittest.TestCase):
         self.assertEqual(len(sliced.irregularlysampledsignals), 1)
         self.assertEqual(len(sliced.epochs), 1)
 
-        assert_same_attributes(sliced.spiketrains[0],
-                               st.time_shift(- time_slice[0]).time_slice(
-                                   t_start=0 * pq.s, t_stop=time_slice[1] - time_slice[0]))
+        assert_same_attributes(
+            sliced.spiketrains[0],
+            st.time_shift(-time_slice[0]).time_slice(t_start=0 * pq.s, t_stop=time_slice[1] - time_slice[0]),
+        )
 
         anasig_target = anasig.copy()
-        anasig_target = anasig_target.time_shift(- time_slice[0]).time_slice(t_start=0 * pq.s,
-                                                                             t_stop=time_slice[1] - time_slice[0])
+        anasig_target = anasig_target.time_shift(-time_slice[0]).time_slice(
+            t_start=0 * pq.s, t_stop=time_slice[1] - time_slice[0]
+        )
         assert_same_attributes(sliced.analogsignals[0], anasig_target)
         irrsig_target = irrsig.copy()
-        irrsig_target = irrsig_target.time_shift(- time_slice[0]).time_slice(t_start=0 * pq.s,
-                                                                             t_stop=time_slice[1] - time_slice[0])
+        irrsig_target = irrsig_target.time_shift(-time_slice[0]).time_slice(
+            t_start=0 * pq.s, t_stop=time_slice[1] - time_slice[0]
+        )
         assert_same_attributes(sliced.irregularlysampledsignals[0], irrsig_target)
-        assert_same_attributes(sliced.events[0],
-                               event.time_shift(- time_slice[0]).time_slice(
-                                   t_start=0 * pq.s, t_stop=time_slice[1] - time_slice[0]))
-        assert_same_attributes(sliced.epochs[0],
-                               epoch2.time_shift(- time_slice[0]).time_slice(t_start=0 * pq.s,
-                                                                             t_stop=time_slice[1] - time_slice[0]))
+        assert_same_attributes(
+            sliced.events[0],
+            event.time_shift(-time_slice[0]).time_slice(t_start=0 * pq.s, t_stop=time_slice[1] - time_slice[0]),
+        )
+        assert_same_attributes(
+            sliced.epochs[0],
+            epoch2.time_shift(-time_slice[0]).time_slice(t_start=0 * pq.s, t_stop=time_slice[1] - time_slice[0]),
+        )
 
         seg = Segment()
 
-        reader = ExampleRawIO(filename='my_filename.fake')
+        reader = ExampleRawIO(filename="my_filename.fake")
         reader.parse_header()
 
-        proxy_anasig = AnalogSignalProxy(rawio=reader,
-                                        stream_index=0, inner_stream_channels=None,
-                                        block_index=0, seg_index=0)
+        proxy_anasig = AnalogSignalProxy(
+            rawio=reader, stream_index=0, inner_stream_channels=None, block_index=0, seg_index=0
+        )
         seg.analogsignals.append(proxy_anasig)
 
-        proxy_st = SpikeTrainProxy(rawio=reader, spike_channel_index=0,
-                                   block_index=0, seg_index=0)
+        proxy_st = SpikeTrainProxy(rawio=reader, spike_channel_index=0, block_index=0, seg_index=0)
         seg.spiketrains.append(proxy_st)
 
-        proxy_event = EventProxy(rawio=reader, event_channel_index=0,
-                                 block_index=0, seg_index=0)
+        proxy_event = EventProxy(rawio=reader, event_channel_index=0, block_index=0, seg_index=0)
         seg.events.append(proxy_event)
 
-        proxy_epoch = EpochProxy(rawio=reader, event_channel_index=1,
-                                 block_index=0, seg_index=0)
-        proxy_epoch.annotate(pick='me')
+        proxy_epoch = EpochProxy(rawio=reader, event_channel_index=1, block_index=0, seg_index=0)
+        proxy_epoch.annotate(pick="me")
         seg.epochs.append(proxy_epoch)
 
         loaded_epoch = proxy_epoch.load()
@@ -561,42 +542,33 @@ class TestSegment(unittest.TestCase):
 
         block = Block()
         block.segments = [seg]
-        block.create_many_to_one_relationship()
+        block.check_relationships()
 
         # test with proxy objects
         sliced = seg.time_slice(time_slice[0], time_slice[1])
 
         assert_neo_object_is_compliant(sliced)
 
-        sliced_event = loaded_event.time_slice(t_start=time_slice[0],
-                                               t_stop=time_slice[1])
+        sliced_event = loaded_event.time_slice(t_start=time_slice[0], t_stop=time_slice[1])
         has_event = len(sliced_event) > 0
 
-        sliced_anasig = loaded_anasig.time_slice(t_start=time_slice[0],
-                                                 t_stop=time_slice[1])
+        sliced_anasig = loaded_anasig.time_slice(t_start=time_slice[0], t_stop=time_slice[1])
 
-        sliced_st = loaded_st.time_slice(t_start=time_slice[0],
-                                         t_stop=time_slice[1])
+        sliced_st = loaded_st.time_slice(t_start=time_slice[0], t_stop=time_slice[1])
 
         self.assertEqual(len(sliced.events), int(has_event))
         self.assertEqual(len(sliced.spiketrains), 1)
         self.assertEqual(len(sliced.analogsignals), 1)
 
-        self.assertTrue(isinstance(sliced.spiketrains[0],
-                                   SpikeTrain))
-        assert_same_attributes(sliced.spiketrains[0],
-                               sliced_st)
+        self.assertTrue(isinstance(sliced.spiketrains[0], SpikeTrain))
+        assert_same_attributes(sliced.spiketrains[0], sliced_st)
 
-        self.assertTrue(isinstance(sliced.analogsignals[0],
-                                   AnalogSignal))
-        assert_same_attributes(sliced.analogsignals[0],
-                               sliced_anasig)
+        self.assertTrue(isinstance(sliced.analogsignals[0], AnalogSignal))
+        assert_same_attributes(sliced.analogsignals[0], sliced_anasig)
 
         if has_event:
-            self.assertTrue(isinstance(sliced.events[0],
-                                       Event))
-            assert_same_attributes(sliced.events[0],
-                                   sliced_event)
+            self.assertTrue(isinstance(sliced.events[0], Event))
+            assert_same_attributes(sliced.events[0], sliced_event)
 
     def test_time_slice_None(self):
         time_slices = [(None, 5.0 * pq.s), (5.0 * pq.s, None), (None, None)]
@@ -607,7 +579,7 @@ class TestSegment(unittest.TestCase):
 
         block = Block()
         block.segments = [seg]
-        block.create_many_to_one_relationship()
+        block.check_relationships()
 
         # test without resetting the time
         for t_start, t_stop in time_slices:
@@ -626,10 +598,7 @@ class TestSegment(unittest.TestCase):
             self.assertEqual(exp_t_stop, sliced.t_stop)
 
     def test__deepcopy(self):
-        childconts = ('analogsignals',
-                      'epochs', 'events',
-                      'irregularlysampledsignals',
-                      'spiketrains')
+        childconts = ("analogsignals", "epochs", "events", "irregularlysampledsignals", "spiketrains")
         for segment in self.segments:
             seg1_copy = deepcopy(segment)
 
@@ -642,6 +611,34 @@ class TestSegment(unittest.TestCase):
                 for child in getattr(seg1_copy, childtype, []):
                     self.assertEqual(id(child.segment), id(seg1_copy))
 
+    def test_add(self):
+        seg = Segment()
+
+        reader = ExampleRawIO(filename="my_filename.fake")
+        reader.parse_header()
+
+        proxy_anasig = AnalogSignalProxy(
+            rawio=reader, stream_index=0, inner_stream_channels=None, block_index=0, seg_index=0
+        )
+        seg.add(proxy_anasig)
+        assert len(seg.analogsignals) == 1
+
+        proxy_st = SpikeTrainProxy(rawio=reader, spike_channel_index=0, block_index=0, seg_index=0)
+        seg.add(proxy_st)
+        assert len(seg.spiketrains) == 1
+
+        proxy_event = EventProxy(rawio=reader, event_channel_index=0, block_index=0, seg_index=0)
+        seg.add(proxy_event)
+        assert len(seg.events) == 1
+
+        proxy_epoch = EpochProxy(rawio=reader, event_channel_index=1, block_index=0, seg_index=0)
+        seg.add(proxy_epoch)
+        assert len(seg.epochs) == 1
+
+    def test_add_invalid_type_raises_Exception(self):
+        seg = Segment()
+        self.assertRaises(TypeError, seg.add, Block())
+
 
 if __name__ == "__main__":
     unittest.main()
