@@ -1,6 +1,7 @@
 """
 Test of neo.io.asciiimageio
 """
+
 import os
 import unittest
 import quantities as pq
@@ -11,7 +12,7 @@ import numpy as np
 class TestAsciiImageIO(unittest.TestCase):
 
     def test_read_txt(self):
-        img = ''
+        img = ""
         img_list = []
         for frame in range(20):
             img_list.append([])
@@ -19,7 +20,7 @@ class TestAsciiImageIO(unittest.TestCase):
                 img_list[frame].append([])
                 for x in range(50):
                     img += str(x)
-                    img += '\t'
+                    img += "\t"
                     img_list[frame][y].append(x)
         img_list = np.array(img_list)
         file_name = "txt_test_file.txt"
@@ -27,9 +28,15 @@ class TestAsciiImageIO(unittest.TestCase):
         file.write(str(img))
         file.close()
 
-        object = AsciiImageIO(file_name='txt_test_file.txt',
-                              nb_frame=20, nb_row=50, nb_column=50, units='V',
-                              sampling_rate=1 * pq.Hz, spatial_scale=1 * pq.micrometer)
+        object = AsciiImageIO(
+            file_name="txt_test_file.txt",
+            nb_frame=20,
+            nb_row=50,
+            nb_column=50,
+            units="V",
+            sampling_rate=1 * pq.Hz,
+            spatial_scale=1 * pq.micrometer,
+        )
         block = object.read_block()
         self.assertEqual(len(block.segments), 1)
         self.assertEqual(len(block.segments[0].imagesequences), 1)
