@@ -10,14 +10,14 @@ from neo.test.iotest.common_io_test import BaseTestIO
 
 class TestElphyIO(BaseTestIO, unittest.TestCase):
     ioclass = ElphyIO
-    entities_to_download = [
-        'elphy'
+    entities_to_download = ["elphy"]
+    entities_to_test = [
+        "elphy/DATA1.DAT",
+        "elphy/ElphyExample.DAT",
+        "elphy/ElphyExample_Mode1.dat",
+        "elphy/ElphyExample_Mode2.dat",
+        "elphy/ElphyExample_Mode3.dat",
     ]
-    entities_to_test = ['elphy/DATA1.DAT',
-                        'elphy/ElphyExample.DAT',
-                        'elphy/ElphyExample_Mode1.dat',
-                        'elphy/ElphyExample_Mode2.dat',
-                        'elphy/ElphyExample_Mode3.dat']
 
     def test_read_data(self):
         for filename in self.entities_to_test:
