@@ -5,7 +5,7 @@ Tests of neo.io.igorproio
 import unittest
 
 try:
-    import igor
+    import igor2
 
     HAVE_IGOR = True
 except ImportError:
@@ -17,13 +17,8 @@ from neo.test.iotest.common_io_test import BaseTestIO
 @unittest.skipUnless(HAVE_IGOR, "requires igor")
 class TestIgorIO(BaseTestIO, unittest.TestCase):
     ioclass = IgorIO
-    entities_to_download = [
-        'igor'
-    ]
-    entities_to_test = [
-        'igor/mac-version2.ibw',
-        'igor/win-version2.ibw'
-    ]
+    entities_to_download = ["igor"]
+    entities_to_test = ["igor/mac-version2.ibw", "igor/win-version2.ibw"]
 
 
 if __name__ == "__main__":
