@@ -6,6 +6,7 @@ import unittest
 
 try:
     from klusta import kwik
+
     HAVE_KWIK = True
 except ImportError:
     HAVE_KWIK = False
@@ -17,12 +18,8 @@ from neo.test.iotest.common_io_test import BaseTestIO
 @unittest.skipUnless(HAVE_KWIK, "requires klusta")
 class TestKwikIO(BaseTestIO, unittest.TestCase):
     ioclass = kwikio.KwikIO
-    entities_to_download = [
-        'kwik'
-    ]
-    entities_to_test = [
-        'kwik/neo.kwik'
-    ]
+    entities_to_download = ["kwik"]
+    entities_to_test = ["kwik/neo.kwik"]
 
 
 if __name__ == "__main__":
