@@ -8,22 +8,23 @@ from neo.test.iotest.common_io_test import BaseTestIO
 import numpy as np
 
 
-class TestTdtIO(BaseTestIO, unittest.TestCase, ):
+class TestTdtIO(
+    BaseTestIO,
+    unittest.TestCase,
+):
     ioclass = TdtIO
-    entities_to_download = [
-        'tdt'
-    ]
+    entities_to_download = ["tdt"]
     entities_to_test = [
         # test structure directory with multiple blocks
-        'tdt/aep_05',
+        "tdt/aep_05",
         # test single block
-        'tdt/dataset_0_single_block/512ch_reconly_all-181123_B24_rest.Tdx',
-        'tdt/dataset_1_single_block/ECTest-220207-135355_ECTest_B1.Tdx',
-        'tdt/aep_05/Block-1/aep_05_Block-1.Tdx'
+        "tdt/dataset_0_single_block/512ch_reconly_all-181123_B24_rest.Tdx",
+        "tdt/dataset_1_single_block/ECTest-220207-135355_ECTest_B1.Tdx",
+        "tdt/aep_05/Block-1/aep_05_Block-1.Tdx",
     ]
 
     def test_signal_group_mode(self):
-        dirname = self.get_local_path('tdt/aep_05')
+        dirname = self.get_local_path("tdt/aep_05")
 
         # In this TDT dataset there are 3 signal streams
         nb_sigs_by_stream = [16, 1, 16]
