@@ -32,6 +32,8 @@ class TestSpikeGLXRawIO(BaseTestRawIO, unittest.TestCase):
         "spikeglx/NP2_subset_with_sync",
         # NP-ultra
         "spikeglx/np_ultra_stub",
+        # Filename changed by the user, multi-dock
+        "spikeglx/multi_probe_multi_dock_multi_shank_filename_without_info",
         # CatGT
         "spikeglx/multi_trigger_multi_gate/CatGT/CatGT-A",
         "spikeglx/multi_trigger_multi_gate/CatGT/CatGT-B",
@@ -110,6 +112,42 @@ class TestSpikeGLXRawIO(BaseTestRawIO, unittest.TestCase):
         atol = 0.001
         assert np.allclose(on_diff, 1, atol=atol)
 
+    def test_t_start_reading(self):
+        """Test that t_start values are correctly read for all streams and segments."""
+
+        # Expected t_start values for each stream and segment
+        expected_t_starts = {
+            "imec0.ap": {0: 15.319535472007237, 1: 15.339535431281986, 2: 21.284723325294053, 3: 21.3047232845688},
+            "imec1.ap": {0: 15.319554693264516, 1: 15.339521518106308, 2: 21.284735282142822, 3: 21.304702106984614},
+            "imec0.lf": {0: 15.3191688060872, 1: 15.339168765361949, 2: 21.284356659374016, 3: 21.304356618648765},
+            "imec1.lf": {0: 15.319321358082725, 1: 15.339321516521915, 2: 21.284568614155827, 3: 21.30456877259502},
+        }
+
+        # Initialize the RawIO
+        rawio = SpikeGLXRawIO(self.get_local_path("spikeglx/multi_trigger_multi_gate/SpikeGLX/5-19-2022-CI4"))
+        rawio.parse_header()
+
+        # Get list of stream names
+        stream_names = rawio.header["signal_streams"]["name"]
+
+        # Test t_start for each stream and segment
+        for stream_name, expected_values in expected_t_starts.items():
+            # Get stream index
+            stream_index = list(stream_names).index(stream_name)
+
+            # Check each segment
+            for seg_index, expected_t_start in expected_values.items():
+                actual_t_start = rawio.get_signal_t_start(block_index=0, seg_index=seg_index, stream_index=stream_index)
+
+                # Use numpy.testing for proper float comparison
+                np.testing.assert_allclose(
+                    actual_t_start,
+                    expected_t_start,
+                    rtol=1e-9,
+                    atol=1e-9,
+                    err_msg=f"Mismatch in t_start for stream '{stream_name}', segment {seg_index}",
+                )
+
 
 if __name__ == "__main__":
     unittest.main()
