@@ -12,15 +12,15 @@ def can_use_network():
     """
     Return True if network access is allowed
     """
+
+    if os.environ.get("NEO_TESTS_NO_NETWORK", False):
+        return False
     try:
         import datalad
+
         HAVE_DATALAD = True
     except:
         HAVE_DATALAD = False
     if not HAVE_DATALAD:
         return False
-    if os.environ.get('NOSETESTS_NO_NETWORK', False):
-        return False
-    if os.environ.get('TRAVIS') == 'true':
-        return False
     return True
